@@ -1,8 +1,14 @@
 from pydantic import Field
 from pydantic_schemaorg.Thing import Thing
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Organization import Organization
+from pydantic_schemaorg.Person import Person
+from pydantic_schemaorg.PostalAddress import PostalAddress
+from pydantic_schemaorg.VirtualLocation import VirtualLocation
+from pydantic_schemaorg.Place import Place
 from datetime import datetime, time
+from pydantic_schemaorg.EntryPoint import EntryPoint
+from pydantic_schemaorg.ActionStatusType import ActionStatusType
 
 
 class Action(Thing):
@@ -15,32 +21,32 @@ class Action(Thing):
     See https://schema.org/Action.
 
     """
-
-    result: Optional[Union[List[Thing], Thing]] = Field(
+    type_: str = Field("Action", const=True, alias='@type')
+    result: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="The result produced in the action. e.g. John wrote *a book*.",
     )
-    object: Optional[Union[List[Thing], Thing]] = Field(
+    object: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="The object upon which the action is carried out, whose state is kept intact or changed."
      "Also known as the semantic roles patient, affected or undergoer (which change their"
      "state) or theme (which doesn't). e.g. John read *a book*.",
     )
-    participant: Union[List[Union[Organization, Any]], Union[Organization, Any]] = Field(
+    participant: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="Other co-agents that participated in the action indirectly. e.g. John wrote a book with"
      "*Steve*.",
     )
-    error: Optional[Union[List[Thing], Thing]] = Field(
+    error: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="For failed actions, more information on the cause of the failure.",
     )
-    location: Union[List[Union[str, Any]], Union[str, Any]] = Field(
+    location: Optional[Union[List[Union[str, PostalAddress, VirtualLocation, Place]], Union[str, PostalAddress, VirtualLocation, Place]]] = Field(
         None,
         description="The location of, for example, where an event is happening, where an organization is located,"
      "or where an action takes place.",
     )
-    endTime: Optional[Union[List[Union[datetime, time]], Union[datetime, time]]] = Field(
+    endTime: Optional[Union[List[Union[datetime, time, str]], Union[datetime, time, str]]] = Field(
         None,
         description="The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation),"
      "the time that it is expected to end. For actions that span a period of time, when the action"
@@ -49,24 +55,24 @@ class Action(Thing):
      "Event uses startDate/endDate instead of startTime/endTime, even when describing"
      "dates with times. This situation may be clarified in future revisions.",
     )
-    agent: Union[List[Union[Organization, Any]], Union[Organization, Any]] = Field(
+    agent: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="The direct performer or driver of the action (animate or inanimate). e.g. *John* wrote"
      "a book.",
     )
-    target: Any = Field(
+    target: Optional[Union[List[Union[EntryPoint, str]], Union[EntryPoint, str]]] = Field(
         None,
         description="Indicates a target EntryPoint for an Action.",
     )
-    actionStatus: Any = Field(
+    actionStatus: Optional[Union[List[Union[ActionStatusType, str]], Union[ActionStatusType, str]]] = Field(
         None,
         description="Indicates the current disposition of the Action.",
     )
-    instrument: Optional[Union[List[Thing], Thing]] = Field(
+    instrument: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="The object that helped the agent perform the action. e.g. John wrote a book with *a pen*.",
     )
-    startTime: Optional[Union[List[Union[datetime, time]], Union[datetime, time]]] = Field(
+    startTime: Optional[Union[List[Union[datetime, time, str]], Union[datetime, time, str]]] = Field(
         None,
         description="The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation),"
      "the time that it is expected to start. For actions that span a period of time, when the action"
@@ -75,7 +81,6 @@ class Action(Thing):
      "Event uses startDate/endDate instead of startTime/endTime, even when describing"
      "dates with times. This situation may be clarified in future revisions.",
     )
-    locals().update({"@type": Field("Action", const=True)})
-
+    
 
 Action.update_forward_refs()
