@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Thing import Thing
 from pydantic_schemaorg.Rating import Rating
 
@@ -10,20 +10,19 @@ class AggregateRating(Rating):
     See https://schema.org/AggregateRating.
 
     """
-
-    reviewCount: Optional[Union[List[int], int]] = Field(
+    type_: str = Field("AggregateRating", const=True, alias='@type')
+    reviewCount: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The count of total number of reviews.",
     )
-    ratingCount: Optional[Union[List[int], int]] = Field(
+    ratingCount: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The count of total number of ratings.",
     )
-    itemReviewed: Optional[Union[List[Thing], Thing]] = Field(
+    itemReviewed: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="The item that is being reviewed/rated.",
     )
-    locals().update({"@type": Field("AggregateRating", const=True)})
-
+    
 
 AggregateRating.update_forward_refs()
