@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.BoardingPolicyType import BoardingPolicyType
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.Organization import Organization
 
 
@@ -9,8 +10,8 @@ class Airline(Organization):
     See https://schema.org/Airline.
 
     """
-
-    boardingPolicy: Any = Field(
+    type_: str = Field("Airline", const=True, alias='@type')
+    boardingPolicy: Optional[Union[List[Union[BoardingPolicyType, str]], Union[BoardingPolicyType, str]]] = Field(
         None,
         description="The type of boarding policy used by the airline (e.g. zone-based or group-based).",
     )
@@ -18,7 +19,6 @@ class Airline(Organization):
         None,
         description="IATA identifier for an airline or airport.",
     )
-    locals().update({"@type": Field("Airline", const=True)})
-
+    
 
 Airline.update_forward_refs()
