@@ -1,6 +1,8 @@
 from pydantic import Field
+from pydantic_schemaorg.PostalAddress import PostalAddress
 from pydantic_schemaorg.Place import Place
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.ArchiveOrganization import ArchiveOrganization
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -11,16 +13,15 @@ class ArchiveComponent(CreativeWork):
     See https://schema.org/ArchiveComponent.
 
     """
-
-    itemLocation: Union[List[Union[str, Place, Any]], Union[str, Place, Any]] = Field(
+    type_: str = Field("ArchiveComponent", const=True, alias='@type')
+    itemLocation: Optional[Union[List[Union[str, PostalAddress, Place]], Union[str, PostalAddress, Place]]] = Field(
         None,
         description="Current location of the item.",
     )
-    holdingArchive: Any = Field(
+    holdingArchive: Optional[Union[List[Union[ArchiveOrganization, str]], Union[ArchiveOrganization, str]]] = Field(
         None,
         description="[[ArchiveOrganization]] that holds, keeps or maintains the [[ArchiveComponent]].",
     )
-    locals().update({"@type": Field("ArchiveComponent", const=True)})
-
+    
 
 ArchiveComponent.update_forward_refs()
