@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.ArchiveComponent import ArchiveComponent
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
 
@@ -11,13 +11,12 @@ class ArchiveOrganization(LocalBusiness):
     See https://schema.org/ArchiveOrganization.
 
     """
-
-    archiveHeld: Optional[Union[List[ArchiveComponent], ArchiveComponent]] = Field(
+    type_: str = Field("ArchiveOrganization", const=True, alias='@type')
+    archiveHeld: Optional[Union[List[Union[ArchiveComponent, str]], Union[ArchiveComponent, str]]] = Field(
         None,
         description="Collection, [fonds](https://en.wikipedia.org/wiki/Fonds), or item held, kept"
      "or maintained by an [[ArchiveOrganization]].",
     )
-    locals().update({"@type": Field("ArchiveOrganization", const=True)})
-
+    
 
 ArchiveOrganization.update_forward_refs()
