@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Vessel import Vessel
 
 
@@ -10,16 +10,15 @@ class Artery(Vessel):
     See https://schema.org/Artery.
 
     """
-
-    supplyTo: Optional[Union[List[AnatomicalStructure], AnatomicalStructure]] = Field(
+    type_: str = Field("Artery", const=True, alias='@type')
+    supplyTo: Optional[Union[List[Union[AnatomicalStructure, str]], Union[AnatomicalStructure, str]]] = Field(
         None,
         description="The area to which the artery supplies blood.",
     )
-    arterialBranch: Optional[Union[List[AnatomicalStructure], AnatomicalStructure]] = Field(
+    arterialBranch: Optional[Union[List[Union[AnatomicalStructure, str]], Union[AnatomicalStructure, str]]] = Field(
         None,
         description="The branches that comprise the arterial structure.",
     )
-    locals().update({"@type": Field("Artery", const=True)})
-
+    
 
 Artery.update_forward_refs()
