@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -9,17 +10,16 @@ class Audience(Intangible):
     See https://schema.org/Audience.
 
     """
-
+    type_: str = Field("Audience", const=True, alias='@type')
     audienceType: Optional[Union[List[str], str]] = Field(
         None,
         description="The target group associated with a given audience (e.g. veterans, car owners, musicians,"
      "etc.).",
     )
-    geographicArea: Any = Field(
+    geographicArea: Optional[Union[List[Union[AdministrativeArea, str]], Union[AdministrativeArea, str]]] = Field(
         None,
         description="The geographic area associated with the audience.",
     )
-    locals().update({"@type": Field("Audience", const=True)})
-
+    
 
 Audience.update_forward_refs()
