@@ -1,9 +1,9 @@
 from pydantic import Field
+from pydantic_schemaorg.ContactPoint import ContactPoint
+from pydantic_schemaorg.Audience import Audience
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from pydantic_schemaorg.Audience import Audience
-from pydantic_schemaorg.ContactPoint import ContactPoint
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.AllocateAction import AllocateAction
 
 
@@ -13,12 +13,11 @@ class AuthorizeAction(AllocateAction):
     See https://schema.org/AuthorizeAction.
 
     """
-
-    recipient: Optional[Union[List[Union[Organization, Person, Audience, ContactPoint]], Union[Organization, Person, Audience, ContactPoint]]] = Field(
+    type_: str = Field("AuthorizeAction", const=True, alias='@type')
+    recipient: Optional[Union[List[Union[ContactPoint, Audience, Organization, Person, str]], Union[ContactPoint, Audience, Organization, Person, str]]] = Field(
         None,
         description="A sub property of participant. The participant who is at the receiving end of the action.",
     )
-    locals().update({"@type": Field("AuthorizeAction", const=True)})
-
+    
 
 AuthorizeAction.update_forward_refs()
