@@ -1,5 +1,6 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+from typing import List, Optional, Union
 from pydantic_schemaorg.FinancialProduct import FinancialProduct
 
 
@@ -10,8 +11,8 @@ class BankAccount(FinancialProduct):
     See https://schema.org/BankAccount.
 
     """
-
-    accountMinimumInflow: Any = Field(
+    type_: str = Field("BankAccount", const=True, alias='@type')
+    accountMinimumInflow: Optional[Union[List[Union[MonetaryAmount, str]], Union[MonetaryAmount, str]]] = Field(
         None,
         description="A minimum amount that has to be paid in every month.",
     )
@@ -19,13 +20,12 @@ class BankAccount(FinancialProduct):
         None,
         description="The type of a bank account.",
     )
-    accountOverdraftLimit: Any = Field(
+    accountOverdraftLimit: Optional[Union[List[Union[MonetaryAmount, str]], Union[MonetaryAmount, str]]] = Field(
         None,
         description="An overdraft is an extension of credit from a lending institution when an account reaches"
      "zero. An overdraft allows the individual to continue withdrawing money even if the account"
      "has no funds in it. Basically the bank allows people to borrow a set amount of money.",
     )
-    locals().update({"@type": Field("BankAccount", const=True)})
-
+    
 
 BankAccount.update_forward_refs()
