@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.BlogPosting import BlogPosting
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -11,14 +12,14 @@ class Blog(CreativeWork):
     See https://schema.org/Blog.
 
     """
-
-    blogPosts: Any = Field(
+    type_: str = Field("Blog", const=True, alias='@type')
+    blogPosts: Optional[Union[List[Union[BlogPosting, str]], Union[BlogPosting, str]]] = Field(
         None,
         description="Indicates a post that is part of a [[Blog]]. Note that historically, what we term a \"Blog\""
      "was once known as a \"weblog\", and that what we term a \"BlogPosting\" is now often colloquially"
      "referred to as a \"blog\".",
     )
-    blogPost: Any = Field(
+    blogPost: Optional[Union[List[Union[BlogPosting, str]], Union[BlogPosting, str]]] = Field(
         None,
         description="A posting that is part of this blog.",
     )
@@ -28,7 +29,6 @@ class Blog(CreativeWork):
      "You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L)"
      "for, this serial publication.",
     )
-    locals().update({"@type": Field("Blog", const=True)})
-
+    
 
 Blog.update_forward_refs()
