@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.BoatTerminal import BoatTerminal
+from typing import List, Optional, Union
 from pydantic_schemaorg.Trip import Trip
 
 
@@ -9,16 +10,15 @@ class BoatTrip(Trip):
     See https://schema.org/BoatTrip.
 
     """
-
-    arrivalBoatTerminal: Any = Field(
+    type_: str = Field("BoatTrip", const=True, alias='@type')
+    arrivalBoatTerminal: Optional[Union[List[Union[BoatTerminal, str]], Union[BoatTerminal, str]]] = Field(
         None,
         description="The terminal or port from which the boat arrives.",
     )
-    departureBoatTerminal: Any = Field(
+    departureBoatTerminal: Optional[Union[List[Union[BoatTerminal, str]], Union[BoatTerminal, str]]] = Field(
         None,
         description="The terminal or port from which the boat departs.",
     )
-    locals().update({"@type": Field("BoatTrip", const=True)})
-
+    
 
 BoatTrip.update_forward_refs()
