@@ -1,7 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.TransferAction import TransferAction
 
 
@@ -12,12 +12,11 @@ class BorrowAction(TransferAction):
     See https://schema.org/BorrowAction.
 
     """
-
-    lender: Optional[Union[List[Union[Organization, Person]], Union[Organization, Person]]] = Field(
+    type_: str = Field("BorrowAction", const=True, alias='@type')
+    lender: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="A sub property of participant. The person that lends the object being borrowed.",
     )
-    locals().update({"@type": Field("BorrowAction", const=True)})
-
+    
 
 BorrowAction.update_forward_refs()
