@@ -1,5 +1,6 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from pydantic_schemaorg.AggregateRating import AggregateRating
+from typing import List, Optional, Union
 from pydantic_schemaorg.ImageObject import ImageObject
 from pydantic_schemaorg.Review import Review
 from pydantic_schemaorg.Intangible import Intangible
@@ -12,8 +13,8 @@ class Brand(Intangible):
     See https://schema.org/Brand.
 
     """
-
-    aggregateRating: Any = Field(
+    type_: str = Field("Brand", const=True, alias='@type')
+    aggregateRating: Optional[Union[List[Union[AggregateRating, str]], Union[AggregateRating, str]]] = Field(
         None,
         description="The overall rating, based on a collection of reviews or ratings, of the item.",
     )
@@ -21,15 +22,14 @@ class Brand(Intangible):
         None,
         description="A slogan or motto associated with the item.",
     )
-    logo: Optional[Union[List[Union[AnyUrl, ImageObject]], Union[AnyUrl, ImageObject]]] = Field(
+    logo: Optional[Union[List[Union[AnyUrl, ImageObject, str]], Union[AnyUrl, ImageObject, str]]] = Field(
         None,
         description="An associated logo.",
     )
-    review: Optional[Union[List[Review], Review]] = Field(
+    review: Optional[Union[List[Union[Review, str]], Union[Review, str]]] = Field(
         None,
         description="A review of the item.",
     )
-    locals().update({"@type": Field("Brand", const=True)})
-
+    
 
 Brand.update_forward_refs()
