@@ -1,5 +1,8 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from typing import List, Optional, Union
+from pydantic_schemaorg.BroadcastFrequencySpecification import BroadcastFrequencySpecification
+from pydantic_schemaorg.BroadcastService import BroadcastService
+from pydantic_schemaorg.CableOrSatelliteService import CableOrSatelliteService
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -9,13 +12,13 @@ class BroadcastChannel(Intangible):
     See https://schema.org/BroadcastChannel.
 
     """
-
+    type_: str = Field("BroadcastChannel", const=True, alias='@type')
     broadcastChannelId: Optional[Union[List[str], str]] = Field(
         None,
         description="The unique address by which the BroadcastService can be identified in a provider lineup."
      "In US, this is typically a number.",
     )
-    broadcastFrequency: Union[List[Union[str, Any]], Union[str, Any]] = Field(
+    broadcastFrequency: Optional[Union[List[Union[str, BroadcastFrequencySpecification]], Union[str, BroadcastFrequencySpecification]]] = Field(
         None,
         description="The frequency used for over-the-air broadcasts. Numeric values or simple ranges e.g."
      "87-99. In addition a shortcut idiom is supported for frequences of AM and FM radio channels,"
@@ -25,7 +28,7 @@ class BroadcastChannel(Intangible):
         None,
         description="Genre of the creative work, broadcast channel or group.",
     )
-    providesBroadcastService: Any = Field(
+    providesBroadcastService: Optional[Union[List[Union[BroadcastService, str]], Union[BroadcastService, str]]] = Field(
         None,
         description="The BroadcastService offered on this channel.",
     )
@@ -33,11 +36,10 @@ class BroadcastChannel(Intangible):
         None,
         description="The type of service required to have access to the channel (e.g. Standard or Premium).",
     )
-    inBroadcastLineup: Any = Field(
+    inBroadcastLineup: Optional[Union[List[Union[CableOrSatelliteService, str]], Union[CableOrSatelliteService, str]]] = Field(
         None,
         description="The CableOrSatelliteService offering the channel.",
     )
-    locals().update({"@type": Field("BroadcastChannel", const=True)})
-
+    
 
 BroadcastChannel.update_forward_refs()
