@@ -1,5 +1,5 @@
-from pydantic import Field, StrictBool
-from typing import Any, Union, List, Optional
+from pydantic import StrictBool, Field
+from typing import List, Optional, Union
 from pydantic_schemaorg.Language import Language
 from pydantic_schemaorg.Event import Event
 from pydantic_schemaorg.PublicationEvent import PublicationEvent
@@ -11,8 +11,8 @@ class BroadcastEvent(PublicationEvent):
     See https://schema.org/BroadcastEvent.
 
     """
-
-    isLiveBroadcast: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    type_: str = Field("BroadcastEvent", const=True, alias='@type')
+    isLiveBroadcast: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="True if the broadcast is of a live event.",
     )
@@ -24,11 +24,10 @@ class BroadcastEvent(PublicationEvent):
         None,
         description="The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).",
     )
-    broadcastOfEvent: Optional[Union[List[Event], Event]] = Field(
+    broadcastOfEvent: Optional[Union[List[Union[Event, str]], Union[Event, str]]] = Field(
         None,
         description="The event being broadcast such as a sporting event or awards ceremony.",
     )
-    locals().update({"@type": Field("BroadcastEvent", const=True)})
-
+    
 
 BroadcastEvent.update_forward_refs()
