@@ -1,8 +1,8 @@
 from pydantic import Field
 from pydantic_schemaorg.QualitativeValue import QualitativeValue
-from typing import Any, Union, List, Optional
-from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
+from typing import List, Optional, Any, Union
 from decimal import Decimal
+from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -12,12 +12,12 @@ class BroadcastFrequencySpecification(Intangible):
     See https://schema.org/BroadcastFrequencySpecification.
 
     """
-
+    type_: str = Field("BroadcastFrequencySpecification", const=True, alias='@type')
     broadcastSignalModulation: Optional[Union[List[Union[str, QualitativeValue]], Union[str, QualitativeValue]]] = Field(
         None,
         description="The modulation (e.g. FM, AM, etc) used by a particular broadcast service.",
     )
-    broadcastFrequencyValue: Optional[Union[List[Union[Decimal, QuantitativeValue]], Union[Decimal, QuantitativeValue]]] = Field(
+    broadcastFrequencyValue: Optional[Union[List[Union[Decimal, QuantitativeValue, str]], Union[Decimal, QuantitativeValue, str]]] = Field(
         None,
         description="The frequency in MHz for a particular broadcast.",
     )
@@ -25,7 +25,6 @@ class BroadcastFrequencySpecification(Intangible):
         None,
         description="The subchannel used for the broadcast.",
     )
-    locals().update({"@type": Field("BroadcastFrequencySpecification", const=True)})
-
+    
 
 BroadcastFrequencySpecification.update_forward_refs()
