@@ -1,6 +1,7 @@
 from pydantic import Field
+from pydantic_schemaorg.BusStop import BusStop
 from pydantic_schemaorg.BusStation import BusStation
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.Trip import Trip
 
 
@@ -10,12 +11,12 @@ class BusTrip(Trip):
     See https://schema.org/BusTrip.
 
     """
-
-    departureBusStop: Union[List[Union[BusStation, Any]], Union[BusStation, Any]] = Field(
+    type_: str = Field("BusTrip", const=True, alias='@type')
+    departureBusStop: Optional[Union[List[Union[BusStop, BusStation, str]], Union[BusStop, BusStation, str]]] = Field(
         None,
         description="The stop or station from which the bus departs.",
     )
-    arrivalBusStop: Union[List[Union[BusStation, Any]], Union[BusStation, Any]] = Field(
+    arrivalBusStop: Optional[Union[List[Union[BusStop, BusStation, str]], Union[BusStop, BusStation, str]]] = Field(
         None,
         description="The stop or station from which the bus arrives.",
     )
@@ -27,7 +28,6 @@ class BusTrip(Trip):
         None,
         description="The name of the bus (e.g. Bolt Express).",
     )
-    locals().update({"@type": Field("BusTrip", const=True)})
-
+    
 
 BusTrip.update_forward_refs()
