@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
+from typing import List, Optional, Union
 from pydantic_schemaorg.Audience import Audience
 
 
@@ -10,20 +11,19 @@ class BusinessAudience(Audience):
     See https://schema.org/BusinessAudience.
 
     """
-
-    yearsInOperation: Any = Field(
+    type_: str = Field("BusinessAudience", const=True, alias='@type')
+    yearsInOperation: Optional[Union[List[Union[QuantitativeValue, str]], Union[QuantitativeValue, str]]] = Field(
         None,
         description="The age of the business.",
     )
-    numberOfEmployees: Any = Field(
+    numberOfEmployees: Optional[Union[List[Union[QuantitativeValue, str]], Union[QuantitativeValue, str]]] = Field(
         None,
         description="The number of employees in an organization e.g. business.",
     )
-    yearlyRevenue: Any = Field(
+    yearlyRevenue: Optional[Union[List[Union[QuantitativeValue, str]], Union[QuantitativeValue, str]]] = Field(
         None,
         description="The size of the business in annual revenue.",
     )
-    locals().update({"@type": Field("BusinessAudience", const=True)})
-
+    
 
 BusinessAudience.update_forward_refs()
