@@ -1,7 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.WarrantyPromise import WarrantyPromise
 from pydantic_schemaorg.TradeAction import TradeAction
 
@@ -13,21 +13,20 @@ class BuyAction(TradeAction):
     See https://schema.org/BuyAction.
 
     """
-
-    vendor: Optional[Union[List[Union[Organization, Person]], Union[Organization, Person]]] = Field(
+    type_: str = Field("BuyAction", const=True, alias='@type')
+    vendor: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="'vendor' is an earlier term for 'seller'.",
     )
-    seller: Optional[Union[List[Union[Organization, Person]], Union[Organization, Person]]] = Field(
+    seller: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="An entity which offers (sells / leases / lends / loans) the services / goods. A seller may"
      "also be a provider.",
     )
-    warrantyPromise: Optional[Union[List[WarrantyPromise], WarrantyPromise]] = Field(
+    warrantyPromise: Optional[Union[List[Union[WarrantyPromise, str]], Union[WarrantyPromise, str]]] = Field(
         None,
         description="The warranty promise(s) included in the offer.",
     )
-    locals().update({"@type": Field("BuyAction", const=True)})
-
+    
 
 BuyAction.update_forward_refs()
