@@ -1,5 +1,6 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from typing import List, Optional, Union
+from pydantic_schemaorg.CategoryCodeSet import CategoryCodeSet
 from pydantic_schemaorg.DefinedTerm import DefinedTerm
 
 
@@ -9,16 +10,15 @@ class CategoryCode(DefinedTerm):
     See https://schema.org/CategoryCode.
 
     """
-
+    type_: str = Field("CategoryCode", const=True, alias='@type')
     codeValue: Optional[Union[List[str], str]] = Field(
         None,
         description="A short textual code that uniquely identifies the value.",
     )
-    inCodeSet: Union[List[Union[AnyUrl, Any]], Union[AnyUrl, Any]] = Field(
+    inCodeSet: Optional[Union[List[Union[AnyUrl, CategoryCodeSet, str]], Union[AnyUrl, CategoryCodeSet, str]]] = Field(
         None,
         description="A [[CategoryCodeSet]] that contains this category code.",
     )
-    locals().update({"@type": Field("CategoryCode", const=True)})
-
+    
 
 CategoryCode.update_forward_refs()
