@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.DefinedTerm import DefinedTerm
 from pydantic_schemaorg.BioChemEntity import BioChemEntity
 
@@ -11,21 +11,20 @@ class ChemicalSubstance(BioChemEntity):
     See https://schema.org/ChemicalSubstance.
 
     """
-
+    type_: str = Field("ChemicalSubstance", const=True, alias='@type')
     chemicalComposition: Optional[Union[List[str], str]] = Field(
         None,
         description="The chemical composition describes the identity and relative ratio of the chemical"
      "elements that make up the substance.",
     )
-    chemicalRole: Optional[Union[List[DefinedTerm], DefinedTerm]] = Field(
+    chemicalRole: Optional[Union[List[Union[DefinedTerm, str]], Union[DefinedTerm, str]]] = Field(
         None,
         description="A role played by the BioChemEntity within a chemical context.",
     )
-    potentialUse: Optional[Union[List[DefinedTerm], DefinedTerm]] = Field(
+    potentialUse: Optional[Union[List[Union[DefinedTerm, str]], Union[DefinedTerm, str]]] = Field(
         None,
         description="Intended use of the BioChemEntity by humans.",
     )
-    locals().update({"@type": Field("ChemicalSubstance", const=True)})
-
+    
 
 ChemicalSubstance.update_forward_refs()
