@@ -1,6 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.Property import Property
+from typing import List, Optional, Union
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -10,12 +11,11 @@ class Class(Intangible):
     See https://schema.org/Class.
 
     """
-
-    supersededBy: Union[List[Union[Enumeration, Any]], Union[Enumeration, Any]] = Field(
+    type_: str = Field("Class", const=True, alias='@type')
+    supersededBy: Optional[Union[List[Union['Class', Enumeration, Property, str]], Union['Class', Enumeration, Property, str]]] = Field(
         None,
         description="Relates a term (i.e. a property, class or enumeration) to one that supersedes it.",
     )
-    locals().update({"@type": Field("Class", const=True)})
-
+    
 
 Class.update_forward_refs()
