@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -9,12 +9,11 @@ class Collection(CreativeWork):
     See https://schema.org/Collection.
 
     """
-
-    collectionSize: Optional[Union[List[int], int]] = Field(
+    type_: str = Field("Collection", const=True, alias='@type')
+    collectionSize: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The number of items in the [[Collection]].",
     )
-    locals().update({"@type": Field("Collection", const=True)})
-
+    
 
 Collection.update_forward_refs()
