@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.PublicationIssue import PublicationIssue
 
 
@@ -14,17 +14,17 @@ class ComicIssue(PublicationIssue):
     See https://schema.org/ComicIssue.
 
     """
-
-    colorist: Optional[Union[List[Person], Person]] = Field(
+    type_: str = Field("ComicIssue", const=True, alias='@type')
+    colorist: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="The individual who adds color to inked drawings.",
     )
-    artist: Optional[Union[List[Person], Person]] = Field(
+    artist: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="The primary artist for a work in a medium other than pencils or digital line art--for example,"
      "if the primary artwork is done in watercolors or digital paints.",
     )
-    letterer: Optional[Union[List[Person], Person]] = Field(
+    letterer: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="The individual who adds lettering, including speech balloons and sound effects, to"
      "artwork.",
@@ -34,15 +34,14 @@ class ComicIssue(PublicationIssue):
         description="A description of the variant cover for the issue, if the issue is a variant printing. For"
      "example, \"Bryan Hitch Variant Cover\" or \"2nd Printing Variant\".",
     )
-    penciler: Optional[Union[List[Person], Person]] = Field(
+    penciler: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="The individual who draws the primary narrative artwork.",
     )
-    inker: Optional[Union[List[Person], Person]] = Field(
+    inker: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="The individual who traces over the pencil drawings in ink after pencils are complete.",
     )
-    locals().update({"@type": Field("ComicIssue", const=True)})
-
+    
 
 ComicIssue.update_forward_refs()
