@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -10,20 +10,19 @@ class Comment(CreativeWork):
     See https://schema.org/Comment.
 
     """
-
-    downvoteCount: Optional[Union[List[int], int]] = Field(
+    type_: str = Field("Comment", const=True, alias='@type')
+    downvoteCount: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The number of downvotes this question, answer or comment has received from the community.",
     )
-    upvoteCount: Optional[Union[List[int], int]] = Field(
+    upvoteCount: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The number of upvotes this question, answer or comment has received from the community.",
     )
-    parentItem: Any = Field(
+    parentItem: Optional[Union[List[Union['Comment', str]], Union['Comment', str]]] = Field(
         None,
         description="The parent of a question, answer or item in general.",
     )
-    locals().update({"@type": Field("Comment", const=True)})
-
+    
 
 Comment.update_forward_refs()
