@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Comment import Comment
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CommunicateAction import CommunicateAction
 
 
@@ -10,12 +10,11 @@ class CommentAction(CommunicateAction):
     See https://schema.org/CommentAction.
 
     """
-
-    resultComment: Optional[Union[List[Comment], Comment]] = Field(
+    type_: str = Field("CommentAction", const=True, alias='@type')
+    resultComment: Optional[Union[List[Union[Comment, str]], Union[Comment, str]]] = Field(
         None,
         description="A sub property of result. The Comment created or sent as a result of this action.",
     )
-    locals().update({"@type": Field("CommentAction", const=True)})
-
+    
 
 CommentAction.update_forward_refs()
