@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalCondition import MedicalCondition
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom
 from pydantic_schemaorg.MedicalIntangible import MedicalIntangible
 
@@ -12,18 +12,17 @@ class DDxElement(MedicalIntangible):
     See https://schema.org/DDxElement.
 
     """
-
-    diagnosis: Optional[Union[List[MedicalCondition], MedicalCondition]] = Field(
+    type_: str = Field("DDxElement", const=True, alias='@type')
+    diagnosis: Optional[Union[List[Union[MedicalCondition, str]], Union[MedicalCondition, str]]] = Field(
         None,
         description="One or more alternative conditions considered in the differential diagnosis process"
      "as output of a diagnosis process.",
     )
-    distinguishingSign: Optional[Union[List[MedicalSignOrSymptom], MedicalSignOrSymptom]] = Field(
+    distinguishingSign: Optional[Union[List[Union[MedicalSignOrSymptom, str]], Union[MedicalSignOrSymptom, str]]] = Field(
         None,
         description="One of a set of signs and symptoms that can be used to distinguish this diagnosis from others"
      "in the differential diagnosis.",
     )
-    locals().update({"@type": Field("DDxElement", const=True)})
-
+    
 
 DDxElement.update_forward_refs()
