@@ -1,5 +1,6 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from typing import List, Optional, Union
+from pydantic_schemaorg.Dataset import Dataset
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -9,7 +10,7 @@ class DataCatalog(CreativeWork):
     See https://schema.org/DataCatalog.
 
     """
-
+    type_: str = Field("DataCatalog", const=True, alias='@type')
     measurementTechnique: Optional[Union[List[Union[AnyUrl, str]], Union[AnyUrl, str]]] = Field(
         None,
         description="A technique or technology used in a [[Dataset]] (or [[DataDownload]], [[DataCatalog]]),"
@@ -24,11 +25,10 @@ class DataCatalog(CreativeWork):
      "several [[variableMeasured]] properties recorded for some given data object, use"
      "a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]].",
     )
-    dataset: Any = Field(
+    dataset: Optional[Union[List[Union[Dataset, str]], Union[Dataset, str]]] = Field(
         None,
         description="A dataset contained in this catalog.",
     )
-    locals().update({"@type": Field("DataCatalog", const=True)})
-
+    
 
 DataCatalog.update_forward_refs()
