@@ -1,7 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.Thing import Thing
 from pydantic_schemaorg.DataFeedItem import DataFeedItem
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Dataset import Dataset
 
 
@@ -11,12 +11,11 @@ class DataFeed(Dataset):
     See https://schema.org/DataFeed.
 
     """
-
+    type_: str = Field("DataFeed", const=True, alias='@type')
     dataFeedElement: Optional[Union[List[Union[str, Thing, DataFeedItem]], Union[str, Thing, DataFeedItem]]] = Field(
         None,
         description="An item within in a data feed. Data feeds may have many elements.",
     )
-    locals().update({"@type": Field("DataFeed", const=True)})
-
+    
 
 DataFeed.update_forward_refs()
