@@ -1,6 +1,6 @@
 from pydantic import Field
-from datetime import date, datetime
-from typing import Any, Union, List, Optional
+from datetime import datetime, date
+from typing import List, Optional, Union
 from pydantic_schemaorg.Thing import Thing
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -11,25 +11,24 @@ class DataFeedItem(Intangible):
     See https://schema.org/DataFeedItem.
 
     """
-
-    dateDeleted: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    type_: str = Field("DataFeedItem", const=True, alias='@type')
+    dateDeleted: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The datetime the item was removed from the DataFeed.",
     )
-    item: Optional[Union[List[Thing], Thing]] = Field(
+    item: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists')’.",
     )
-    dateModified: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    dateModified: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The date on which the CreativeWork was most recently modified or when the item's entry"
      "was modified within a DataFeed.",
     )
-    dateCreated: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    dateCreated: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The date on which the CreativeWork was created or the item was added to a DataFeed.",
     )
-    locals().update({"@type": Field("DataFeedItem", const=True)})
-
+    
 
 DataFeedItem.update_forward_refs()
