@@ -1,7 +1,8 @@
 from pydantic import Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
-from datetime import date, datetime
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+from typing import List, Optional, Any, Union
+from datetime import datetime, date
 from pydantic_schemaorg.StructuredValue import StructuredValue
 
 
@@ -14,16 +15,16 @@ class DatedMoneySpecification(StructuredValue):
     See https://schema.org/DatedMoneySpecification.
 
     """
-
-    amount: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    type_: str = Field("DatedMoneySpecification", const=True, alias='@type')
+    amount: Optional[Union[List[Union[Decimal, MonetaryAmount, str]], Union[Decimal, MonetaryAmount, str]]] = Field(
         None,
         description="The amount of money.",
     )
-    endDate: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    endDate: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
     )
-    startDate: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    startDate: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
     )
@@ -35,7 +36,6 @@ class DatedMoneySpecification(StructuredValue):
      "e.g. \"BTC\"; well known names for [Local Exchange Tradings Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system)"
      "(LETS) and other currency types e.g. \"Ithaca HOUR\".",
     )
-    locals().update({"@type": Field("DatedMoneySpecification", const=True)})
-
+    
 
 DatedMoneySpecification.update_forward_refs()
