@@ -1,5 +1,6 @@
-from pydantic import Field, AnyUrl
-from typing import Any, Union, List, Optional
+from pydantic import AnyUrl, Field
+from typing import List, Optional, Union
+from pydantic_schemaorg.DefinedTermSet import DefinedTermSet
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -13,16 +14,15 @@ class DefinedTerm(Intangible):
     See https://schema.org/DefinedTerm.
 
     """
-
+    type_: str = Field("DefinedTerm", const=True, alias='@type')
     termCode: Optional[Union[List[str], str]] = Field(
         None,
         description="A code that identifies this [[DefinedTerm]] within a [[DefinedTermSet]]",
     )
-    inDefinedTermSet: Union[List[Union[AnyUrl, Any]], Union[AnyUrl, Any]] = Field(
+    inDefinedTermSet: Optional[Union[List[Union[AnyUrl, DefinedTermSet, str]], Union[AnyUrl, DefinedTermSet, str]]] = Field(
         None,
         description="A [[DefinedTermSet]] that contains this term.",
     )
-    locals().update({"@type": Field("DefinedTerm", const=True)})
-
+    
 
 DefinedTerm.update_forward_refs()
