@@ -1,6 +1,7 @@
-from pydantic import Field, StrictBool
+from pydantic import StrictBool, Field
 from pydantic_schemaorg.DefinedRegion import DefinedRegion
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
+from pydantic_schemaorg.ShippingDeliveryTime import ShippingDeliveryTime
 from pydantic_schemaorg.StructuredValue import StructuredValue
 
 
@@ -13,13 +14,13 @@ class DeliveryTimeSettings(StructuredValue):
     See https://schema.org/DeliveryTimeSettings.
 
     """
-
-    shippingDestination: Optional[Union[List[DefinedRegion], DefinedRegion]] = Field(
+    type_: str = Field("DeliveryTimeSettings", const=True, alias='@type')
+    shippingDestination: Optional[Union[List[Union[DefinedRegion, str]], Union[DefinedRegion, str]]] = Field(
         None,
         description="indicates (possibly multiple) shipping destinations. These can be defined in several"
      "ways e.g. postalCode ranges.",
     )
-    isUnlabelledFallback: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    isUnlabelledFallback: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]]"
      "or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]]"
@@ -28,7 +29,7 @@ class DeliveryTimeSettings(StructuredValue):
      "(for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]),"
      "since this property is for use with unlabelled settings.",
     )
-    deliveryTime: Any = Field(
+    deliveryTime: Optional[Union[List[Union[ShippingDeliveryTime, str]], Union[ShippingDeliveryTime, str]]] = Field(
         None,
         description="The total delay between the receipt of the order and the goods reaching the final customer.",
     )
@@ -37,7 +38,6 @@ class DeliveryTimeSettings(StructuredValue):
         description="Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within"
      "the context of a [[shippingSettingsLink]] cross-reference).",
     )
-    locals().update({"@type": Field("DeliveryTimeSettings", const=True)})
-
+    
 
 DeliveryTimeSettings.update_forward_refs()
