@@ -10,8 +10,7 @@ class Dentist(MedicalBusiness, LocalBusiness, MedicalOrganization):
     See https://schema.org/Dentist.
 
     """
-
-    locals().update({"@type": Field("Dentist", const=True)})
-
+    type_: str = Field("Dentist", const=True, alias='@type')
+    
 
 Dentist.update_forward_refs()
