@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalTest import MedicalTest
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalOrganization import MedicalOrganization
 
 
@@ -10,12 +10,11 @@ class DiagnosticLab(MedicalOrganization):
     See https://schema.org/DiagnosticLab.
 
     """
-
-    availableTest: Optional[Union[List[MedicalTest], MedicalTest]] = Field(
+    type_: str = Field("DiagnosticLab", const=True, alias='@type')
+    availableTest: Optional[Union[List[Union[MedicalTest, str]], Union[MedicalTest, str]]] = Field(
         None,
         description="A diagnostic test or procedure offered by this lab.",
     )
-    locals().update({"@type": Field("DiagnosticLab", const=True)})
-
+    
 
 DiagnosticLab.update_forward_refs()
