@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.DigitalDocumentPermission import DigitalDocumentPermission
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -9,14 +10,13 @@ class DigitalDocument(CreativeWork):
     See https://schema.org/DigitalDocument.
 
     """
-
-    hasDigitalDocumentPermission: Any = Field(
+    type_: str = Field("DigitalDocument", const=True, alias='@type')
+    hasDigitalDocumentPermission: Optional[Union[List[Union[DigitalDocumentPermission, str]], Union[DigitalDocumentPermission, str]]] = Field(
         None,
         description="A permission related to the access to this document (e.g. permission to read or write"
      "an electronic document). For a public document, specify a grantee with an Audience with"
      "audienceType equal to \"public\".",
     )
-    locals().update({"@type": Field("DigitalDocument", const=True)})
-
+    
 
 DigitalDocument.update_forward_refs()
