@@ -1,10 +1,10 @@
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPermissionType
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.ContactPoint import ContactPoint
+from pydantic_schemaorg.Audience import Audience
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from pydantic_schemaorg.Audience import Audience
-from pydantic_schemaorg.ContactPoint import ContactPoint
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -14,16 +14,15 @@ class DigitalDocumentPermission(Intangible):
     See https://schema.org/DigitalDocumentPermission.
 
     """
-
-    permissionType: Optional[Union[List[DigitalDocumentPermissionType], DigitalDocumentPermissionType]] = Field(
+    type_: str = Field("DigitalDocumentPermission", const=True, alias='@type')
+    permissionType: Optional[Union[List[Union[DigitalDocumentPermissionType, str]], Union[DigitalDocumentPermissionType, str]]] = Field(
         None,
         description="The type of permission granted the person, organization, or audience.",
     )
-    grantee: Optional[Union[List[Union[Organization, Person, Audience, ContactPoint]], Union[Organization, Person, Audience, ContactPoint]]] = Field(
+    grantee: Optional[Union[List[Union[ContactPoint, Audience, Organization, Person, str]], Union[ContactPoint, Audience, Organization, Person, str]]] = Field(
         None,
         description="The person, organization, contact point, or audience that has been granted this permission.",
     )
-    locals().update({"@type": Field("DigitalDocumentPermission", const=True)})
-
+    
 
 DigitalDocumentPermission.update_forward_refs()
