@@ -1,9 +1,9 @@
 from pydantic import Field
+from pydantic_schemaorg.ContactPoint import ContactPoint
+from pydantic_schemaorg.Audience import Audience
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from pydantic_schemaorg.Audience import Audience
-from pydantic_schemaorg.ContactPoint import ContactPoint
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.TradeAction import TradeAction
 
 
@@ -14,12 +14,11 @@ class DonateAction(TradeAction):
     See https://schema.org/DonateAction.
 
     """
-
-    recipient: Optional[Union[List[Union[Organization, Person, Audience, ContactPoint]], Union[Organization, Person, Audience, ContactPoint]]] = Field(
+    type_: str = Field("DonateAction", const=True, alias='@type')
+    recipient: Optional[Union[List[Union[ContactPoint, Audience, Organization, Person, str]], Union[ContactPoint, Audience, Organization, Person, str]]] = Field(
         None,
         description="A sub property of participant. The participant who is at the receiving end of the action.",
     )
-    locals().update({"@type": Field("DonateAction", const=True)})
-
+    
 
 DonateAction.update_forward_refs()
