@@ -1,6 +1,7 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from decimal import Decimal
+from pydantic_schemaorg.QualitativeValue import QualitativeValue
 from pydantic_schemaorg.MedicalIntangible import MedicalIntangible
 
 
@@ -10,13 +11,13 @@ class DoseSchedule(MedicalIntangible):
     See https://schema.org/DoseSchedule.
 
     """
-
+    type_: str = Field("DoseSchedule", const=True, alias='@type')
     targetPopulation: Optional[Union[List[str], str]] = Field(
         None,
         description="Characteristics of the population for which this is intended, or which typically uses"
      "it, e.g. 'adults'.",
     )
-    doseValue: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    doseValue: Optional[Union[List[Union[Decimal, QualitativeValue, str]], Union[Decimal, QualitativeValue, str]]] = Field(
         None,
         description="The value of the dose, e.g. 500.",
     )
@@ -28,7 +29,6 @@ class DoseSchedule(MedicalIntangible):
         None,
         description="How often the dose is taken, e.g. 'daily'.",
     )
-    locals().update({"@type": Field("DoseSchedule", const=True)})
-
+    
 
 DoseSchedule.update_forward_refs()
