@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Drug import Drug
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
 
 
@@ -11,12 +11,11 @@ class DrugClass(MedicalEntity):
     See https://schema.org/DrugClass.
 
     """
-
-    drug: Optional[Union[List[Drug], Drug]] = Field(
+    type_: str = Field("DrugClass", const=True, alias='@type')
+    drug: Optional[Union[List[Union[Drug, str]], Union[Drug, str]]] = Field(
         None,
         description="Specifying a drug or medicine used in a medication procedure.",
     )
-    locals().update({"@type": Field("DrugClass", const=True)})
-
+    
 
 DrugClass.update_forward_refs()
