@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalIntangible import MedicalIntangible
 
 
@@ -10,12 +10,11 @@ class DrugLegalStatus(MedicalIntangible):
     See https://schema.org/DrugLegalStatus.
 
     """
-
-    applicableLocation: Optional[Union[List[AdministrativeArea], AdministrativeArea]] = Field(
+    type_: str = Field("DrugLegalStatus", const=True, alias='@type')
+    applicableLocation: Optional[Union[List[Union[AdministrativeArea, str]], Union[AdministrativeArea, str]]] = Field(
         None,
         description="The location in which the status applies.",
     )
-    locals().update({"@type": Field("DrugLegalStatus", const=True)})
-
+    
 
 DrugLegalStatus.update_forward_refs()
