@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CivicStructure import CivicStructure
 from pydantic_schemaorg.Organization import Organization
 
@@ -11,12 +11,11 @@ class EducationalOrganization(CivicStructure, Organization):
     See https://schema.org/EducationalOrganization.
 
     """
-
-    alumni: Optional[Union[List[Person], Person]] = Field(
+    type_: str = Field("EducationalOrganization", const=True, alias='@type')
+    alumni: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="Alumni of an organization.",
     )
-    locals().update({"@type": Field("EducationalOrganization", const=True)})
-
+    
 
 EducationalOrganization.update_forward_refs()
