@@ -1,7 +1,8 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
-from pydantic_schemaorg.PriceSpecification import PriceSpecification
+from typing import List, Optional, Union
 from decimal import Decimal
+from pydantic_schemaorg.PriceSpecification import PriceSpecification
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
 from pydantic_schemaorg.OrganizationRole import OrganizationRole
 
 
@@ -11,17 +12,16 @@ class EmployeeRole(OrganizationRole):
     See https://schema.org/EmployeeRole.
 
     """
-
+    type_: str = Field("EmployeeRole", const=True, alias='@type')
     salaryCurrency: Optional[Union[List[str], str]] = Field(
         None,
         description="The currency (coded using [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217) )"
      "used for the main salary information in this job posting or for this employee.",
     )
-    baseSalary: Union[List[Union[Decimal, PriceSpecification, Any]], Union[Decimal, PriceSpecification, Any]] = Field(
+    baseSalary: Optional[Union[List[Union[Decimal, PriceSpecification, MonetaryAmount, str]], Union[Decimal, PriceSpecification, MonetaryAmount, str]]] = Field(
         None,
         description="The base salary of the job or of an employee in an EmployeeRole.",
     )
-    locals().update({"@type": Field("EmployeeRole", const=True)})
-
+    
 
 EmployeeRole.update_forward_refs()
