@@ -1,5 +1,7 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.Class import Class
+from pydantic_schemaorg.Property import Property
+from typing import List, Optional, Union
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -9,12 +11,11 @@ class Enumeration(Intangible):
     See https://schema.org/Enumeration.
 
     """
-
-    supersededBy: Any = Field(
+    type_: str = Field("Enumeration", const=True, alias='@type')
+    supersededBy: Optional[Union[List[Union[Class, 'Enumeration', Property, str]], Union[Class, 'Enumeration', Property, str]]] = Field(
         None,
         description="Relates a term (i.e. a property, class or enumeration) to one that supersedes it.",
     )
-    locals().update({"@type": Field("Enumeration", const=True)})
-
+    
 
 Enumeration.update_forward_refs()
