@@ -1,6 +1,7 @@
-from pydantic import Field, AnyUrl
+from pydantic import AnyUrl, Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
+from typing import List, Optional, Union
 from pydantic_schemaorg.Service import Service
 
 
@@ -12,8 +13,8 @@ class FinancialProduct(Service):
     See https://schema.org/FinancialProduct.
 
     """
-
-    annualPercentageRate: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    type_: str = Field("FinancialProduct", const=True, alias='@type')
+    annualPercentageRate: Optional[Union[List[Union[Decimal, QuantitativeValue, str]], Union[Decimal, QuantitativeValue, str]]] = Field(
         None,
         description="The annual rate that is charged for borrowing (or made by investing), expressed as a single"
      "percentage number that represents the actual yearly cost of funds over the term of a loan."
@@ -24,12 +25,11 @@ class FinancialProduct(Service):
         description="Description of fees, commissions, and other terms applied either to a class of financial"
      "product, or by a financial service organization.",
     )
-    interestRate: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    interestRate: Optional[Union[List[Union[Decimal, QuantitativeValue, str]], Union[Decimal, QuantitativeValue, str]]] = Field(
         None,
         description="The interest rate, charged or paid, applicable to the financial product. Note: This"
      "is different from the calculated annualPercentageRate.",
     )
-    locals().update({"@type": Field("FinancialProduct", const=True)})
-
+    
 
 FinancialProduct.update_forward_refs()
