@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Service import Service
 
@@ -12,19 +12,18 @@ class GovernmentService(Service):
     See https://schema.org/GovernmentService.
 
     """
-
+    type_: str = Field("GovernmentService", const=True, alias='@type')
     jurisdiction: Optional[Union[List[Union[str, AdministrativeArea]], Union[str, AdministrativeArea]]] = Field(
         None,
         description="Indicates a legal jurisdiction, e.g. of some legislation, or where some government"
      "service is based.",
     )
-    serviceOperator: Optional[Union[List[Organization], Organization]] = Field(
+    serviceOperator: Optional[Union[List[Union[Organization, str]], Union[Organization, str]]] = Field(
         None,
         description="The operating organization, if different from the provider. This enables the representation"
      "of services that are provided by an organization, but operated by another organization"
      "like a subcontractor.",
     )
-    locals().update({"@type": Field("GovernmentService", const=True)})
-
+    
 
 GovernmentService.update_forward_refs()
