@@ -1,16 +1,15 @@
 from pydantic import Field
-from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 from pydantic_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness
+from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 
 
-class HealthClub(SportsActivityLocation, HealthAndBeautyBusiness):
+class HealthClub(HealthAndBeautyBusiness, SportsActivityLocation):
     """A health club.
 
     See https://schema.org/HealthClub.
 
     """
-
-    locals().update({"@type": Field("HealthClub", const=True)})
-
+    type_: str = Field("HealthClub", const=True, alias='@type')
+    
 
 HealthClub.update_forward_refs()
