@@ -1,5 +1,5 @@
-from pydantic import Field, StrictBool
-from typing import Any, Union, List, Optional
+from pydantic import StrictBool, Field
+from typing import List, Optional, Union
 from pydantic_schemaorg.Intangible import Intangible
 
 
@@ -10,8 +10,8 @@ class HealthPlanFormulary(Intangible):
     See https://schema.org/HealthPlanFormulary.
 
     """
-
-    offersPrescriptionByMail: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    type_: str = Field("HealthPlanFormulary", const=True, alias='@type')
+    offersPrescriptionByMail: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="Whether prescriptions can be delivered by mail.",
     )
@@ -19,11 +19,10 @@ class HealthPlanFormulary(Intangible):
         None,
         description="The tier(s) of drugs offered by this formulary or insurance plan.",
     )
-    healthPlanCostSharing: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    healthPlanCostSharing: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="Whether The costs to the patient for services under this network or formulary.",
     )
-    locals().update({"@type": Field("HealthPlanFormulary", const=True)})
-
+    
 
 HealthPlanFormulary.update_forward_refs()
