@@ -1,6 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.BedDetails import BedDetails
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.BedType import BedType
+from typing import List, Optional, Union
 from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
 from pydantic_schemaorg.Room import Room
 
@@ -12,22 +13,21 @@ class HotelRoom(Room):
     See https://schema.org/HotelRoom.
 
     """
-
-    bed: Union[List[Union[str, BedDetails, Any]], Union[str, BedDetails, Any]] = Field(
+    type_: str = Field("HotelRoom", const=True, alias='@type')
+    bed: Optional[Union[List[Union[str, BedDetails, BedType]], Union[str, BedDetails, BedType]]] = Field(
         None,
         description="The type of bed or beds included in the accommodation. For the single case of just one bed"
      "of a certain type, you use bed directly with a text. If you want to indicate the quantity"
      "of a certain kind of bed, use an instance of BedDetails. For more detailed information,"
      "use the amenityFeature property.",
     )
-    occupancy: Optional[Union[List[QuantitativeValue], QuantitativeValue]] = Field(
+    occupancy: Optional[Union[List[Union[QuantitativeValue, str]], Union[QuantitativeValue, str]]] = Field(
         None,
         description="The allowed total occupancy for the accommodation in persons (including infants etc)."
      "For individual accommodations, this is not necessarily the legal maximum but defines"
      "the permitted usage as per the contractual agreement (e.g. a double room used by a single"
      "person). Typical unit code(s): C62 for person",
     )
-    locals().update({"@type": Field("HotelRoom", const=True)})
-
+    
 
 HotelRoom.update_forward_refs()
