@@ -1,7 +1,7 @@
 from pydantic import Field
-from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
+from typing import List, Optional, Union
 from pydantic_schemaorg.Accommodation import Accommodation
 
 
@@ -12,14 +12,13 @@ class House(Accommodation):
     See https://schema.org/House.
 
     """
-
-    numberOfRooms: Optional[Union[List[Union[Decimal, QuantitativeValue]], Union[Decimal, QuantitativeValue]]] = Field(
+    type_: str = Field("House", const=True, alias='@type')
+    numberOfRooms: Optional[Union[List[Union[Decimal, QuantitativeValue, str]], Union[Decimal, QuantitativeValue, str]]] = Field(
         None,
         description="The number of rooms (excluding bathrooms and closets) of the accommodation or lodging"
      "business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be"
      "put in the unitText property of the QuantitativeValue.",
     )
-    locals().update({"@type": Field("House", const=True)})
-
+    
 
 House.update_forward_refs()
