@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+from typing import List, Optional, Union
 from pydantic_schemaorg.HowToItem import HowToItem
 
 
@@ -9,12 +10,11 @@ class HowToSupply(HowToItem):
     See https://schema.org/HowToSupply.
 
     """
-
-    estimatedCost: Union[List[Union[str, Any]], Union[str, Any]] = Field(
+    type_: str = Field("HowToSupply", const=True, alias='@type')
+    estimatedCost: Optional[Union[List[Union[str, MonetaryAmount]], Union[str, MonetaryAmount]]] = Field(
         None,
         description="The estimated cost of the supply or supplies consumed when performing instructions.",
     )
-    locals().update({"@type": Field("HowToSupply", const=True)})
-
+    
 
 HowToSupply.update_forward_refs()
