@@ -1,9 +1,9 @@
 from pydantic import Field
-from pydantic_schemaorg.CreativeWork import CreativeWork
 from pydantic_schemaorg.ListItem import ListItem
+from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
-class HowToTip(CreativeWork, ListItem):
+class HowToTip(ListItem, CreativeWork):
     """An explanation in the instructions for how to achieve a result. It provides supplementary"
      "information about a technique, supply, author's preference, etc. It can explain what"
      "could be done, or what should not be done, but doesn't specify what should be done (see"
@@ -12,8 +12,7 @@ class HowToTip(CreativeWork, ListItem):
     See https://schema.org/HowToTip.
 
     """
-
-    locals().update({"@type": Field("HowToTip", const=True)})
-
+    type_: str = Field("HowToTip", const=True, alias='@type')
+    
 
 HowToTip.update_forward_refs()
