@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MediaObject import MediaObject
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.HyperTocEntry import HyperTocEntry
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -15,16 +15,15 @@ class HyperToc(CreativeWork):
     See https://schema.org/HyperToc.
 
     """
-
-    associatedMedia: Optional[Union[List[MediaObject], MediaObject]] = Field(
+    type_: str = Field("HyperToc", const=True, alias='@type')
+    associatedMedia: Optional[Union[List[Union[MediaObject, str]], Union[MediaObject, str]]] = Field(
         None,
         description="A media object that encodes this CreativeWork. This property is a synonym for encoding.",
     )
-    tocEntry: Optional[Union[List[HyperTocEntry], HyperTocEntry]] = Field(
+    tocEntry: Optional[Union[List[Union[HyperTocEntry, str]], Union[HyperTocEntry, str]]] = Field(
         None,
         description="Indicates a [[HyperTocEntry]] in a [[HyperToc]].",
     )
-    locals().update({"@type": Field("HyperToc", const=True)})
-
+    
 
 HyperToc.update_forward_refs()
