@@ -1,5 +1,5 @@
-from pydantic import Field, StrictBool
-from typing import Any, Union, List, Optional
+from pydantic import StrictBool, Field
+from typing import List, Optional, Union
 from pydantic_schemaorg.PropertyValue import PropertyValue
 from pydantic_schemaorg.MediaObject import MediaObject
 
@@ -10,8 +10,8 @@ class ImageObject(MediaObject):
     See https://schema.org/ImageObject.
 
     """
-
-    thumbnail: Any = Field(
+    type_: str = Field("ImageObject", const=True, alias='@type')
+    thumbnail: Optional[Union[List[Union['ImageObject', str]], Union['ImageObject', str]]] = Field(
         None,
         description="Thumbnail image for an image or video.",
     )
@@ -19,7 +19,7 @@ class ImageObject(MediaObject):
         None,
         description="Represents textual captioning from a [[MediaObject]], e.g. text of a 'meme'.",
     )
-    representativeOfPage: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    representativeOfPage: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="Indicates whether this image is representative of the content of the page.",
     )
@@ -32,7 +32,6 @@ class ImageObject(MediaObject):
         description="The caption for this object. For downloadable machine formats (closed caption, subtitles"
      "etc.) use MediaObject and indicate the [[encodingFormat]].",
     )
-    locals().update({"@type": Field("ImageObject", const=True)})
-
+    
 
 ImageObject.update_forward_refs()
