@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalTest import MedicalTest
 
 
@@ -10,12 +10,11 @@ class ImagingTest(MedicalTest):
     See https://schema.org/ImagingTest.
 
     """
-
-    imagingTechnique: Optional[Union[List[MedicalImagingTechnique], MedicalImagingTechnique]] = Field(
+    type_: str = Field("ImagingTest", const=True, alias='@type')
+    imagingTechnique: Optional[Union[List[Union[MedicalImagingTechnique, str]], Union[MedicalImagingTechnique, str]]] = Field(
         None,
         description="Imaging technique used.",
     )
-    locals().update({"@type": Field("ImagingTest", const=True)})
-
+    
 
 ImagingTest.update_forward_refs()
