@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.Product import Product
 
 
@@ -9,13 +9,12 @@ class IndividualProduct(Product):
     See https://schema.org/IndividualProduct.
 
     """
-
+    type_: str = Field("IndividualProduct", const=True, alias='@type')
     serialNumber: Optional[Union[List[str], str]] = Field(
         None,
         description="The serial number or any alphanumeric identifier of a particular product. When attached"
      "to an offer, it is a shortcut for the serial number of the product included in the offer.",
     )
-    locals().update({"@type": Field("IndividualProduct", const=True)})
-
+    
 
 IndividualProduct.update_forward_refs()
