@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 from pydantic_schemaorg.MedicalCondition import MedicalCondition
 
 
@@ -12,7 +13,7 @@ class InfectiousDisease(MedicalCondition):
     See https://schema.org/InfectiousDisease.
 
     """
-
+    type_: str = Field("InfectiousDisease", const=True, alias='@type')
     transmissionMethod: Optional[Union[List[str], str]] = Field(
         None,
         description="How the disease spreads, either as a route or vector, for example 'direct contact', 'Aedes"
@@ -22,11 +23,10 @@ class InfectiousDisease(MedicalCondition):
         None,
         description="The actual infectious agent, such as a specific bacterium.",
     )
-    infectiousAgentClass: Any = Field(
+    infectiousAgentClass: Optional[Union[List[Union[InfectiousAgentClass, str]], Union[InfectiousAgentClass, str]]] = Field(
         None,
         description="The class of infectious agent (bacteria, prion, etc.) that causes the disease.",
     )
-    locals().update({"@type": Field("InfectiousDisease", const=True)})
-
+    
 
 InfectiousDisease.update_forward_refs()
