@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.Event import Event
+from typing import List, Optional, Union
 from pydantic_schemaorg.CommunicateAction import CommunicateAction
 
 
@@ -10,12 +11,11 @@ class InformAction(CommunicateAction):
     See https://schema.org/InformAction.
 
     """
-
-    event: Any = Field(
+    type_: str = Field("InformAction", const=True, alias='@type')
+    event: Optional[Union[List[Union[Event, str]], Union[Event, str]]] = Field(
         None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
-    locals().update({"@type": Field("InformAction", const=True)})
-
+    
 
 InformAction.update_forward_refs()
