@@ -1,6 +1,7 @@
 from pydantic import Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+from typing import List, Optional, Union
 from pydantic_schemaorg.FinancialProduct import FinancialProduct
 
 
@@ -11,12 +12,11 @@ class InvestmentOrDeposit(FinancialProduct):
     See https://schema.org/InvestmentOrDeposit.
 
     """
-
-    amount: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    type_: str = Field("InvestmentOrDeposit", const=True, alias='@type')
+    amount: Optional[Union[List[Union[Decimal, MonetaryAmount, str]], Union[Decimal, MonetaryAmount, str]]] = Field(
         None,
         description="The amount of money.",
     )
-    locals().update({"@type": Field("InvestmentOrDeposit", const=True)})
-
+    
 
 InvestmentOrDeposit.update_forward_refs()
