@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CommunicateAction import CommunicateAction
 
 
@@ -10,12 +10,11 @@ class InviteAction(CommunicateAction):
     See https://schema.org/InviteAction.
 
     """
-
-    event: Optional[Union[List[Event], Event]] = Field(
+    type_: str = Field("InviteAction", const=True, alias='@type')
+    event: Optional[Union[List[Union[Event, str]], Union[Event, str]]] = Field(
         None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
-    locals().update({"@type": Field("InviteAction", const=True)})
-
+    
 
 InviteAction.update_forward_refs()
