@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.Event import Event
+from typing import List, Optional, Union
 from pydantic_schemaorg.InteractAction import InteractAction
 
 
@@ -13,12 +14,11 @@ class JoinAction(InteractAction):
     See https://schema.org/JoinAction.
 
     """
-
-    event: Any = Field(
+    type_: str = Field("JoinAction", const=True, alias='@type')
+    event: Optional[Union[List[Union[Event, str]], Union[Event, str]]] = Field(
         None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
-    locals().update({"@type": Field("JoinAction", const=True)})
-
+    
 
 JoinAction.update_forward_refs()
