@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.InteractAction import InteractAction
 
 
@@ -12,12 +12,11 @@ class LeaveAction(InteractAction):
     See https://schema.org/LeaveAction.
 
     """
-
-    event: Optional[Union[List[Event], Event]] = Field(
+    type_: str = Field("LeaveAction", const=True, alias='@type')
+    event: Optional[Union[List[Union[Event, str]], Union[Event, str]]] = Field(
         None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
-    locals().update({"@type": Field("LeaveAction", const=True)})
-
+    
 
 LeaveAction.update_forward_refs()
