@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.TransferAction import TransferAction
 
 
@@ -11,12 +11,11 @@ class LendAction(TransferAction):
     See https://schema.org/LendAction.
 
     """
-
-    borrower: Optional[Union[List[Person], Person]] = Field(
+    type_: str = Field("LendAction", const=True, alias='@type')
+    borrower: Optional[Union[List[Union[Person, str]], Union[Person, str]]] = Field(
         None,
         description="A sub property of participant. The person that borrows the object being lent.",
     )
-    locals().update({"@type": Field("LendAction", const=True)})
-
+    
 
 LendAction.update_forward_refs()
