@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Thing import Thing
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -10,24 +10,23 @@ class ListItem(Intangible):
     See https://schema.org/ListItem.
 
     """
-
+    type_: str = Field("ListItem", const=True, alias='@type')
     position: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The position of an item in a series or sequence of items.",
     )
-    nextItem: Any = Field(
+    nextItem: Optional[Union[List[Union['ListItem', str]], Union['ListItem', str]]] = Field(
         None,
         description="A link to the ListItem that follows the current one.",
     )
-    previousItem: Any = Field(
+    previousItem: Optional[Union[List[Union['ListItem', str]], Union['ListItem', str]]] = Field(
         None,
         description="A link to the ListItem that preceeds the current one.",
     )
-    item: Optional[Union[List[Thing], Thing]] = Field(
+    item: Optional[Union[List[Union[Thing, str]], Union[Thing, str]]] = Field(
         None,
         description="An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists')’.",
     )
-    locals().update({"@type": Field("ListItem", const=True)})
-
+    
 
 ListItem.update_forward_refs()
