@@ -1,6 +1,6 @@
 from pydantic import Field
 from datetime import datetime
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.BlogPosting import BlogPosting
 
 
@@ -11,23 +11,22 @@ class LiveBlogPosting(BlogPosting):
     See https://schema.org/LiveBlogPosting.
 
     """
-
-    coverageEndTime: Optional[Union[List[datetime], datetime]] = Field(
+    type_: str = Field("LiveBlogPosting", const=True, alias='@type')
+    coverageEndTime: Optional[Union[List[Union[datetime, str]], Union[datetime, str]]] = Field(
         None,
         description="The time when the live blog will stop covering the Event. Note that coverage may continue"
      "after the Event concludes.",
     )
-    liveBlogUpdate: Optional[Union[List[BlogPosting], BlogPosting]] = Field(
+    liveBlogUpdate: Optional[Union[List[Union[BlogPosting, str]], Union[BlogPosting, str]]] = Field(
         None,
         description="An update to the LiveBlog.",
     )
-    coverageStartTime: Optional[Union[List[datetime], datetime]] = Field(
+    coverageStartTime: Optional[Union[List[Union[datetime, str]], Union[datetime, str]]] = Field(
         None,
         description="The time when the live blog will begin covering the Event. Note that coverage may begin"
      "before the Event's start time. The LiveBlogPosting may also be created before coverage"
      "begins.",
     )
-    locals().update({"@type": Field("LiveBlogPosting", const=True)})
-
+    
 
 LiveBlogPosting.update_forward_refs()
