@@ -1,6 +1,7 @@
 from pydantic import Field
-from datetime import date, datetime
-from typing import Any, Union, List, Optional
+from datetime import datetime, date
+from typing import List, Optional, Union
+from pydantic_schemaorg.OpeningHoursSpecification import OpeningHoursSpecification
 from pydantic_schemaorg.PropertyValue import PropertyValue
 
 
@@ -11,21 +12,20 @@ class LocationFeatureSpecification(PropertyValue):
     See https://schema.org/LocationFeatureSpecification.
 
     """
-
-    validFrom: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    type_: str = Field("LocationFeatureSpecification", const=True, alias='@type')
+    validFrom: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The date when the item becomes valid.",
     )
-    validThrough: Optional[Union[List[Union[datetime, date]], Union[datetime, date]]] = Field(
+    validThrough: Optional[Union[List[Union[datetime, date, str]], Union[datetime, date, str]]] = Field(
         None,
         description="The date after when the item is not valid. For example the end of an offer, salary period,"
      "or a period of opening hours.",
     )
-    hoursAvailable: Any = Field(
+    hoursAvailable: Optional[Union[List[Union[OpeningHoursSpecification, str]], Union[OpeningHoursSpecification, str]]] = Field(
         None,
         description="The hours during which this service or contact is available.",
     )
-    locals().update({"@type": Field("LocationFeatureSpecification", const=True)})
-
+    
 
 LocationFeatureSpecification.update_forward_refs()
