@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
 from datetime import datetime, time
 from pydantic_schemaorg.QualitativeValue import QualitativeValue
@@ -14,24 +14,24 @@ class LodgingReservation(Reservation):
     See https://schema.org/LodgingReservation.
 
     """
-
+    type_: str = Field("LodgingReservation", const=True, alias='@type')
     lodgingUnitDescription: Optional[Union[List[str], str]] = Field(
         None,
         description="A full description of the lodging unit.",
     )
-    numChildren: Optional[Union[List[Union[int, QuantitativeValue]], Union[int, QuantitativeValue]]] = Field(
+    numChildren: Optional[Union[List[Union[int, QuantitativeValue, str]], Union[int, QuantitativeValue, str]]] = Field(
         None,
         description="The number of children staying in the unit.",
     )
-    checkinTime: Optional[Union[List[Union[datetime, time]], Union[datetime, time]]] = Field(
+    checkinTime: Optional[Union[List[Union[datetime, time, str]], Union[datetime, time, str]]] = Field(
         None,
         description="The earliest someone may check into a lodging establishment.",
     )
-    numAdults: Optional[Union[List[Union[int, QuantitativeValue]], Union[int, QuantitativeValue]]] = Field(
+    numAdults: Optional[Union[List[Union[int, QuantitativeValue, str]], Union[int, QuantitativeValue, str]]] = Field(
         None,
         description="The number of adults staying in the unit.",
     )
-    checkoutTime: Optional[Union[List[Union[datetime, time]], Union[datetime, time]]] = Field(
+    checkoutTime: Optional[Union[List[Union[datetime, time, str]], Union[datetime, time, str]]] = Field(
         None,
         description="The latest someone may check out of a lodging establishment.",
     )
@@ -39,7 +39,6 @@ class LodgingReservation(Reservation):
         None,
         description="Textual description of the unit type (including suite vs. room, size of bed, etc.).",
     )
-    locals().update({"@type": Field("LodgingReservation", const=True)})
-
+    
 
 LodgingReservation.update_forward_refs()
