@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MapCategoryType import MapCategoryType
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -10,12 +10,11 @@ class Map(CreativeWork):
     See https://schema.org/Map.
 
     """
-
-    mapType: Optional[Union[List[MapCategoryType], MapCategoryType]] = Field(
+    type_: str = Field("Map", const=True, alias='@type')
+    mapType: Optional[Union[List[Union[MapCategoryType, str]], Union[MapCategoryType, str]]] = Field(
         None,
         description="Indicates the kind of Map, from the MapCategoryType Enumeration.",
     )
-    locals().update({"@type": Field("Map", const=True)})
-
+    
 
 Map.update_forward_refs()
