@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.SolveMathAction import SolveMathAction
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -9,14 +10,13 @@ class MathSolver(CreativeWork):
     See https://schema.org/MathSolver.
 
     """
-
-    mathExpression: Union[List[Union[str, Any]], Union[str, Any]] = Field(
+    type_: str = Field("MathSolver", const=True, alias='@type')
+    mathExpression: Optional[Union[List[Union[str, SolveMathAction]], Union[str, SolveMathAction]]] = Field(
         None,
         description="A mathematical expression (e.g. 'x^2-3x=0') that may be solved for a specific variable,"
      "simplified, or transformed. This can take many formats, e.g. LaTeX, Ascii-Math, or"
      "math as you would write with a keyboard.",
     )
-    locals().update({"@type": Field("MathSolver", const=True)})
-
+    
 
 MathSolver.update_forward_refs()
