@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MediaObject import MediaObject
+from typing import List, Optional, Union
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -11,13 +12,12 @@ class MediaReviewItem(CreativeWork):
     See https://schema.org/MediaReviewItem.
 
     """
-
-    mediaItemAppearance: Any = Field(
+    type_: str = Field("MediaReviewItem", const=True, alias='@type')
+    mediaItemAppearance: Optional[Union[List[Union[MediaObject, str]], Union[MediaObject, str]]] = Field(
         None,
         description="In the context of a [[MediaReview]], indicates specific media item(s) that are grouped"
      "using a [[MediaReviewItem]].",
     )
-    locals().update({"@type": Field("MediaReviewItem", const=True)})
-
+    
 
 MediaReviewItem.update_forward_refs()
