@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Offer import Offer
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -11,19 +11,18 @@ class MediaSubscription(Intangible):
     See https://schema.org/MediaSubscription.
 
     """
-
-    expectsAcceptanceOf: Optional[Union[List[Offer], Offer]] = Field(
+    type_: str = Field("MediaSubscription", const=True, alias='@type')
+    expectsAcceptanceOf: Optional[Union[List[Union[Offer, str]], Union[Offer, str]]] = Field(
         None,
         description="An Offer which must be accepted before the user can perform the Action. For example, the"
      "user may need to buy a movie before being able to watch it.",
     )
-    authenticator: Optional[Union[List[Organization], Organization]] = Field(
+    authenticator: Optional[Union[List[Union[Organization, str]], Union[Organization, str]]] = Field(
         None,
         description="The Organization responsible for authenticating the user's subscription. For example,"
      "many media apps require a cable/satellite provider to authenticate your subscription"
      "before playing media.",
     )
-    locals().update({"@type": Field("MediaSubscription", const=True)})
-
+    
 
 MediaSubscription.update_forward_refs()
