@@ -9,8 +9,7 @@ class MedicalAudience(Audience, PeopleAudience):
     See https://schema.org/MedicalAudience.
 
     """
-
-    locals().update({"@type": Field("MedicalAudience", const=True)})
-
+    type_: str = Field("MedicalAudience", const=True, alias='@type')
+    
 
 MedicalAudience.update_forward_refs()
