@@ -1,9 +1,9 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.MedicalTest import MedicalTest
 from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
 from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
-from pydantic_schemaorg.MedicalTest import MedicalTest
 from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 from pydantic_schemaorg.MedicalOrganization import MedicalOrganization
 
@@ -16,16 +16,15 @@ class MedicalClinic(MedicalBusiness, MedicalOrganization):
     See https://schema.org/MedicalClinic.
 
     """
-
-    medicalSpecialty: Optional[Union[List[MedicalSpecialty], MedicalSpecialty]] = Field(
+    type_: str = Field("MedicalClinic", const=True, alias='@type')
+    medicalSpecialty: Optional[Union[List[Union[MedicalSpecialty, str]], Union[MedicalSpecialty, str]]] = Field(
         None,
         description="A medical specialty of the provider.",
     )
-    availableService: Optional[Union[List[Union[MedicalProcedure, MedicalTherapy, MedicalTest]], Union[MedicalProcedure, MedicalTherapy, MedicalTest]]] = Field(
+    availableService: Optional[Union[List[Union[MedicalTest, MedicalProcedure, MedicalTherapy, str]], Union[MedicalTest, MedicalProcedure, MedicalTherapy, str]]] = Field(
         None,
         description="A medical service available from this provider.",
     )
-    locals().update({"@type": Field("MedicalClinic", const=True)})
-
+    
 
 MedicalClinic.update_forward_refs()
