@@ -1,6 +1,6 @@
 from pydantic import Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.MedicalIntangible import MedicalIntangible
 
 
@@ -10,8 +10,8 @@ class MedicalConditionStage(MedicalIntangible):
     See https://schema.org/MedicalConditionStage.
 
     """
-
-    stageAsNumber: Optional[Union[List[Decimal], Decimal]] = Field(
+    type_: str = Field("MedicalConditionStage", const=True, alias='@type')
+    stageAsNumber: Optional[Union[List[Union[Decimal, str]], Union[Decimal, str]]] = Field(
         None,
         description="The stage represented as a number, e.g. 3.",
     )
@@ -19,7 +19,6 @@ class MedicalConditionStage(MedicalIntangible):
         None,
         description="The substage, e.g. 'a' for Stage IIIa.",
     )
-    locals().update({"@type": Field("MedicalConditionStage", const=True)})
-
+    
 
 MedicalConditionStage.update_forward_refs()
