@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservationalStudyDesign
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalStudy import MedicalStudy
 
 
@@ -15,12 +16,11 @@ class MedicalObservationalStudy(MedicalStudy):
     See https://schema.org/MedicalObservationalStudy.
 
     """
-
-    studyDesign: Any = Field(
+    type_: str = Field("MedicalObservationalStudy", const=True, alias='@type')
+    studyDesign: Optional[Union[List[Union[MedicalObservationalStudyDesign, str]], Union[MedicalObservationalStudyDesign, str]]] = Field(
         None,
         description="Specifics about the observational study design (enumerated).",
     )
-    locals().update({"@type": Field("MedicalObservationalStudy", const=True)})
-
+    
 
 MedicalObservationalStudy.update_forward_refs()
