@@ -1,6 +1,6 @@
-from pydantic import Field, StrictBool
+from pydantic import StrictBool, Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.Organization import Organization
 
 
@@ -10,12 +10,12 @@ class MedicalOrganization(Organization):
     See https://schema.org/MedicalOrganization.
 
     """
-
-    medicalSpecialty: Optional[Union[List[MedicalSpecialty], MedicalSpecialty]] = Field(
+    type_: str = Field("MedicalOrganization", const=True, alias='@type')
+    medicalSpecialty: Optional[Union[List[Union[MedicalSpecialty, str]], Union[MedicalSpecialty, str]]] = Field(
         None,
         description="A medical specialty of the provider.",
     )
-    isAcceptingNewPatients: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    isAcceptingNewPatients: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="Whether the provider is accepting new patients.",
     )
@@ -24,7 +24,6 @@ class MedicalOrganization(Organization):
         description="Name or unique ID of network. (Networks are often reused across different insurance"
      "plans).",
     )
-    locals().update({"@type": Field("MedicalOrganization", const=True)})
-
+    
 
 MedicalOrganization.update_forward_refs()
