@@ -1,8 +1,9 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MedicalProcedureType import MedicalProcedureType
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
-from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 from pydantic_schemaorg.EventStatusType import EventStatusType
+from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
 
 class MedicalProcedure(MedicalEntity):
@@ -12,8 +13,8 @@ class MedicalProcedure(MedicalEntity):
     See https://schema.org/MedicalProcedure.
 
     """
-
-    procedureType: Any = Field(
+    type_: str = Field("MedicalProcedure", const=True, alias='@type')
+    procedureType: Optional[Union[List[Union[MedicalProcedureType, str]], Union[MedicalProcedureType, str]]] = Field(
         None,
         description="The type of procedure, for example Surgical, Noninvasive, or Percutaneous.",
     )
@@ -25,7 +26,7 @@ class MedicalProcedure(MedicalEntity):
         None,
         description="Typical preparation that a patient must undergo before having the procedure performed.",
     )
-    status: Optional[Union[List[Union[str, MedicalStudyStatus, EventStatusType]], Union[str, MedicalStudyStatus, EventStatusType]]] = Field(
+    status: Optional[Union[List[Union[str, EventStatusType, MedicalStudyStatus]], Union[str, EventStatusType, MedicalStudyStatus]]] = Field(
         None,
         description="The status of the study (enumerated).",
     )
@@ -37,7 +38,6 @@ class MedicalProcedure(MedicalEntity):
         None,
         description="Typical or recommended followup care after the procedure is performed.",
     )
-    locals().update({"@type": Field("MedicalProcedure", const=True)})
-
+    
 
 MedicalProcedure.update_forward_refs()
