@@ -1,6 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.MedicalRiskFactor import MedicalRiskFactor
 
 
 class MedicalRiskEstimator(MedicalEntity):
@@ -10,17 +11,16 @@ class MedicalRiskEstimator(MedicalEntity):
     See https://schema.org/MedicalRiskEstimator.
 
     """
-
-    estimatesRiskOf: Optional[Union[List[MedicalEntity], MedicalEntity]] = Field(
+    type_: str = Field("MedicalRiskEstimator", const=True, alias='@type')
+    estimatesRiskOf: Optional[Union[List[Union[MedicalEntity, str]], Union[MedicalEntity, str]]] = Field(
         None,
         description="The condition, complication, or symptom whose risk is being estimated.",
     )
-    includedRiskFactor: Any = Field(
+    includedRiskFactor: Optional[Union[List[Union[MedicalRiskFactor, str]], Union[MedicalRiskFactor, str]]] = Field(
         None,
         description="A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting"
      "condition.",
     )
-    locals().update({"@type": Field("MedicalRiskEstimator", const=True)})
-
+    
 
 MedicalRiskEstimator.update_forward_refs()
