@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 
 
 class MedicalRiskFactor(MedicalEntity):
@@ -10,12 +10,11 @@ class MedicalRiskFactor(MedicalEntity):
     See https://schema.org/MedicalRiskFactor.
 
     """
-
-    increasesRiskOf: Optional[Union[List[MedicalEntity], MedicalEntity]] = Field(
+    type_: str = Field("MedicalRiskFactor", const=True, alias='@type')
+    increasesRiskOf: Optional[Union[List[Union[MedicalEntity, str]], Union[MedicalEntity, str]]] = Field(
         None,
         description="The condition, complication, etc. influenced by this factor.",
     )
-    locals().update({"@type": Field("MedicalRiskFactor", const=True)})
-
+    
 
 MedicalRiskFactor.update_forward_refs()
