@@ -1,5 +1,5 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.ScholarlyArticle import ScholarlyArticle
 
 
@@ -9,13 +9,12 @@ class MedicalScholarlyArticle(ScholarlyArticle):
     See https://schema.org/MedicalScholarlyArticle.
 
     """
-
+    type_: str = Field("MedicalScholarlyArticle", const=True, alias='@type')
     publicationType: Optional[Union[List[str], str]] = Field(
         None,
         description="The type of the medical article, taken from the US NLM MeSH publication type catalog."
      "See also [MeSH documentation](http://www.nlm.nih.gov/mesh/pubtypes.html).",
     )
-    locals().update({"@type": Field("MedicalScholarlyArticle", const=True)})
-
+    
 
 MedicalScholarlyArticle.update_forward_refs()
