@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalTest import MedicalTest
 from pydantic_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom
 
@@ -12,16 +12,15 @@ class MedicalSign(MedicalSignOrSymptom):
     See https://schema.org/MedicalSign.
 
     """
-
-    identifyingExam: Optional[Union[List[PhysicalExam], PhysicalExam]] = Field(
+    type_: str = Field("MedicalSign", const=True, alias='@type')
+    identifyingExam: Optional[Union[List[Union[PhysicalExam, str]], Union[PhysicalExam, str]]] = Field(
         None,
         description="A physical examination that can identify this sign.",
     )
-    identifyingTest: Optional[Union[List[MedicalTest], MedicalTest]] = Field(
+    identifyingTest: Optional[Union[List[Union[MedicalTest, str]], Union[MedicalTest, str]]] = Field(
         None,
         description="A diagnostic test that can identify this sign.",
     )
-    locals().update({"@type": Field("MedicalSign", const=True)})
-
+    
 
 MedicalSign.update_forward_refs()
