@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalCondition import MedicalCondition
 
 
@@ -11,12 +11,11 @@ class MedicalSignOrSymptom(MedicalCondition):
     See https://schema.org/MedicalSignOrSymptom.
 
     """
-
-    possibleTreatment: Optional[Union[List[MedicalTherapy], MedicalTherapy]] = Field(
+    type_: str = Field("MedicalSignOrSymptom", const=True, alias='@type')
+    possibleTreatment: Optional[Union[List[Union[MedicalTherapy, str]], Union[MedicalTherapy, str]]] = Field(
         None,
         description="A possible treatment to address this condition, sign or symptom.",
     )
-    locals().update({"@type": Field("MedicalSignOrSymptom", const=True)})
-
+    
 
 MedicalSignOrSymptom.update_forward_refs()
