@@ -1,6 +1,10 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MedicalDevice import MedicalDevice
+from typing import List, Optional, Union
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
+from pydantic_schemaorg.Drug import Drug
+from pydantic_schemaorg.MedicalSign import MedicalSign
+from pydantic_schemaorg.MedicalCondition import MedicalCondition
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
 
 
@@ -10,8 +14,8 @@ class MedicalTest(MedicalEntity):
     See https://schema.org/MedicalTest.
 
     """
-
-    usesDevice: Any = Field(
+    type_: str = Field("MedicalTest", const=True, alias='@type')
+    usesDevice: Optional[Union[List[Union[MedicalDevice, str]], Union[MedicalDevice, str]]] = Field(
         None,
         description="Device used to perform the test.",
     )
@@ -19,19 +23,18 @@ class MedicalTest(MedicalEntity):
         None,
         description="Range of acceptable values for a typical patient, when applicable.",
     )
-    affectedBy: Any = Field(
+    affectedBy: Optional[Union[List[Union[Drug, str]], Union[Drug, str]]] = Field(
         None,
         description="Drugs that affect the test's results.",
     )
-    signDetected: Any = Field(
+    signDetected: Optional[Union[List[Union[MedicalSign, str]], Union[MedicalSign, str]]] = Field(
         None,
         description="A sign detected by the test.",
     )
-    usedToDiagnose: Any = Field(
+    usedToDiagnose: Optional[Union[List[Union[MedicalCondition, str]], Union[MedicalCondition, str]]] = Field(
         None,
         description="A condition the test is used to diagnose.",
     )
-    locals().update({"@type": Field("MedicalTest", const=True)})
-
+    
 
 MedicalTest.update_forward_refs()
