@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalTest import MedicalTest
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 
 
 class MedicalTestPanel(MedicalTest):
@@ -9,12 +9,11 @@ class MedicalTestPanel(MedicalTest):
     See https://schema.org/MedicalTestPanel.
 
     """
-
-    subTest: Optional[Union[List[MedicalTest], MedicalTest]] = Field(
+    type_: str = Field("MedicalTestPanel", const=True, alias='@type')
+    subTest: Optional[Union[List[Union[MedicalTest, str]], Union[MedicalTest, str]]] = Field(
         None,
         description="A component test of the panel.",
     )
-    locals().update({"@type": Field("MedicalTestPanel", const=True)})
-
+    
 
 MedicalTestPanel.update_forward_refs()
