@@ -1,7 +1,9 @@
+from typing import List, Optional, Union
+
 from pydantic import Field
-from typing import Any, Union, List, Optional
-from pydantic_schemaorg.MedicalEntity import MedicalEntity
+
 from pydantic_schemaorg.MedicalContraindication import MedicalContraindication
+from pydantic_schemaorg.MedicalEntity import MedicalEntity
 from pydantic_schemaorg.TherapeuticProcedure import TherapeuticProcedure
 
 
@@ -15,24 +17,24 @@ class MedicalTherapy(TherapeuticProcedure):
     See https://schema.org/MedicalTherapy.
 
     """
-
-    duplicateTherapy: Any = Field(
+    type_: str = Field("MedicalTherapy", const=True, alias='@type')
+    duplicateTherapy: Optional[Union[List[Union['MedicalTherapy', str]], Union['MedicalTherapy', str]]] = Field(
         None,
         description="A therapy that duplicates or overlaps this one.",
     )
-    seriousAdverseOutcome: Optional[Union[List[MedicalEntity], MedicalEntity]] = Field(
+    seriousAdverseOutcome: Optional[Union[List[Union[MedicalEntity, str]], Union[MedicalEntity, str]]] = Field(
         None,
         description="A possible serious complication and/or serious side effect of this therapy. Serious"
-     "adverse outcomes include those that are life-threatening; result in death, disability,"
-     "or permanent damage; require hospitalization or prolong existing hospitalization;"
-     "cause congenital anomalies or birth defects; or jeopardize the patient and may require"
-     "medical or surgical intervention to prevent one of the outcomes in this definition.",
+                    "adverse outcomes include those that are life-threatening; result in death, disability,"
+                    "or permanent damage; require hospitalization or prolong existing hospitalization;"
+                    "cause congenital anomalies or birth defects; or jeopardize the patient and may require"
+                    "medical or surgical intervention to prevent one of the outcomes in this definition.",
     )
-    contraindication: Optional[Union[List[Union[str, MedicalContraindication]], Union[str, MedicalContraindication]]] = Field(
+    contraindication: Optional[
+        Union[List[Union[str, MedicalContraindication]], Union[str, MedicalContraindication]]] = Field(
         None,
         description="A contraindication for this therapy.",
     )
-    locals().update({"@type": Field("MedicalTherapy", const=True)})
 
 
 MedicalTherapy.update_forward_refs()
