@@ -1,6 +1,7 @@
 from pydantic import Field
 from pydantic_schemaorg.MedicalAudienceType import MedicalAudienceType
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MedicalAudience import MedicalAudience
+from typing import List, Optional, Any, Union
 from pydantic_schemaorg.WebPage import WebPage
 
 
@@ -10,8 +11,8 @@ class MedicalWebPage(WebPage):
     See https://schema.org/MedicalWebPage.
 
     """
-
-    medicalAudience: Union[List[Union[MedicalAudienceType, Any]], Union[MedicalAudienceType, Any]] = Field(
+    type_: str = Field("MedicalWebPage", const=True, alias='@type')
+    medicalAudience: Optional[Union[List[Union[MedicalAudienceType, MedicalAudience, str]], Union[MedicalAudienceType, MedicalAudience, str]]] = Field(
         None,
         description="Medical audience for page.",
     )
@@ -20,7 +21,6 @@ class MedicalWebPage(WebPage):
         description="An aspect of medical practice that is considered on the page, such as 'diagnosis', 'treatment',"
      "'causes', 'prognosis', 'etiology', 'epidemiology', etc.",
     )
-    locals().update({"@type": Field("MedicalWebPage", const=True)})
-
+    
 
 MedicalWebPage.update_forward_refs()
