@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.MenuSection import MenuSection
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.MenuItem import MenuItem
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -11,16 +11,15 @@ class Menu(CreativeWork):
     See https://schema.org/Menu.
 
     """
-
-    hasMenuSection: Optional[Union[List[MenuSection], MenuSection]] = Field(
+    type_: str = Field("Menu", const=True, alias='@type')
+    hasMenuSection: Optional[Union[List[Union[MenuSection, str]], Union[MenuSection, str]]] = Field(
         None,
         description="A subgrouping of the menu (by dishes, course, serving time period, etc.).",
     )
-    hasMenuItem: Optional[Union[List[MenuItem], MenuItem]] = Field(
+    hasMenuItem: Optional[Union[List[Union[MenuItem, str]], Union[MenuItem, str]]] = Field(
         None,
         description="A food or drink item contained in a menu or menu section.",
     )
-    locals().update({"@type": Field("Menu", const=True)})
-
+    
 
 Menu.update_forward_refs()
