@@ -1,5 +1,6 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.MenuItem import MenuItem
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -11,16 +12,15 @@ class MenuSection(CreativeWork):
     See https://schema.org/MenuSection.
 
     """
-
-    hasMenuSection: Any = Field(
+    type_: str = Field("MenuSection", const=True, alias='@type')
+    hasMenuSection: Optional[Union[List[Union['MenuSection', str]], Union['MenuSection', str]]] = Field(
         None,
         description="A subgrouping of the menu (by dishes, course, serving time period, etc.).",
     )
-    hasMenuItem: Any = Field(
+    hasMenuItem: Optional[Union[List[Union[MenuItem, str]], Union[MenuItem, str]]] = Field(
         None,
         description="A food or drink item contained in a menu or menu section.",
     )
-    locals().update({"@type": Field("MenuSection", const=True)})
-
+    
 
 MenuSection.update_forward_refs()
