@@ -1,8 +1,9 @@
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 from pydantic_schemaorg.Person import Person
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from decimal import Decimal
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
 from pydantic_schemaorg.Grant import Grant
 
 
@@ -12,17 +13,16 @@ class MonetaryGrant(Grant):
     See https://schema.org/MonetaryGrant.
 
     """
-
-    funder: Optional[Union[List[Union[Organization, Person]], Union[Organization, Person]]] = Field(
+    type_: str = Field("MonetaryGrant", const=True, alias='@type')
+    funder: Optional[Union[List[Union[Organization, Person, str]], Union[Organization, Person, str]]] = Field(
         None,
         description="A person or organization that supports (sponsors) something through some kind of financial"
      "contribution.",
     )
-    amount: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    amount: Optional[Union[List[Union[Decimal, MonetaryAmount, str]], Union[Decimal, MonetaryAmount, str]]] = Field(
         None,
         description="The amount of money.",
     )
-    locals().update({"@type": Field("MonetaryGrant", const=True)})
-
+    
 
 MonetaryGrant.update_forward_refs()
