@@ -1,6 +1,7 @@
 from pydantic import Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+from typing import List, Optional, Union
 from pydantic_schemaorg.BankOrCreditUnion import BankOrCreditUnion
 from pydantic_schemaorg.TransferAction import TransferAction
 
@@ -12,8 +13,8 @@ class MoneyTransfer(TransferAction):
     See https://schema.org/MoneyTransfer.
 
     """
-
-    amount: Union[List[Union[Decimal, Any]], Union[Decimal, Any]] = Field(
+    type_: str = Field("MoneyTransfer", const=True, alias='@type')
+    amount: Optional[Union[List[Union[Decimal, MonetaryAmount, str]], Union[Decimal, MonetaryAmount, str]]] = Field(
         None,
         description="The amount of money.",
     )
@@ -22,7 +23,6 @@ class MoneyTransfer(TransferAction):
         description="A bank or bank’s branch, financial institution or international financial institution"
      "operating the beneficiary’s bank account or releasing funds for the beneficiary.",
     )
-    locals().update({"@type": Field("MoneyTransfer", const=True)})
-
+    
 
 MoneyTransfer.update_forward_refs()
