@@ -1,5 +1,6 @@
-from pydantic import Field, StrictBool
-from typing import Any, Union, List, Optional
+from pydantic import StrictBool, Field
+from typing import List, Optional, Union
+from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
 from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
 
 
@@ -10,16 +11,15 @@ class MortgageLoan(LoanOrCredit):
     See https://schema.org/MortgageLoan.
 
     """
-
-    domiciledMortgage: Optional[Union[List[StrictBool], StrictBool]] = Field(
+    type_: str = Field("MortgageLoan", const=True, alias='@type')
+    domiciledMortgage: Optional[Union[List[Union[StrictBool, str]], Union[StrictBool, str]]] = Field(
         None,
         description="Whether borrower is a resident of the jurisdiction where the property is located.",
     )
-    loanMortgageMandateAmount: Any = Field(
+    loanMortgageMandateAmount: Optional[Union[List[Union[MonetaryAmount, str]], Union[MonetaryAmount, str]]] = Field(
         None,
         description="Amount of mortgage mandate that can be converted into a proper mortgage at a later stage.",
     )
-    locals().update({"@type": Field("MortgageLoan", const=True)})
-
+    
 
 MortgageLoan.update_forward_refs()
