@@ -1,6 +1,6 @@
 from pydantic import Field
 from pydantic_schemaorg.Place import Place
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.Action import Action
 
 
@@ -12,17 +12,16 @@ class MoveAction(Action):
     See https://schema.org/MoveAction.
 
     """
-
-    fromLocation: Optional[Union[List[Place], Place]] = Field(
+    type_: str = Field("MoveAction", const=True, alias='@type')
+    fromLocation: Optional[Union[List[Union[Place, str]], Union[Place, str]]] = Field(
         None,
         description="A sub property of location. The original location of the object or the agent before the"
      "action.",
     )
-    toLocation: Optional[Union[List[Place], Place]] = Field(
+    toLocation: Optional[Union[List[Union[Place, str]], Union[Place, str]]] = Field(
         None,
         description="A sub property of location. The final location of the object or the agent after the action.",
     )
-    locals().update({"@type": Field("MoveAction", const=True)})
-
+    
 
 MoveAction.update_forward_refs()
