@@ -1,6 +1,6 @@
 from pydantic import Field
 from decimal import Decimal
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
 from pydantic_schemaorg.EntertainmentBusiness import EntertainmentBusiness
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -11,12 +11,11 @@ class MovieTheater(EntertainmentBusiness, CivicStructure):
     See https://schema.org/MovieTheater.
 
     """
-
-    screenCount: Optional[Union[List[Decimal], Decimal]] = Field(
+    type_: str = Field("MovieTheater", const=True, alias='@type')
+    screenCount: Optional[Union[List[Union[Decimal, str]], Union[Decimal, str]]] = Field(
         None,
         description="The number of screens in the movie theater.",
     )
-    locals().update({"@type": Field("MovieTheater", const=True)})
-
+    
 
 MovieTheater.update_forward_refs()
