@@ -1,5 +1,7 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
+from typing import List, Optional, Union
+from pydantic_schemaorg.MusicRecording import MusicRecording
+from pydantic_schemaorg.ItemList import ItemList
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
 
@@ -9,21 +11,20 @@ class MusicPlaylist(CreativeWork):
     See https://schema.org/MusicPlaylist.
 
     """
-
-    numTracks: Optional[Union[List[int], int]] = Field(
+    type_: str = Field("MusicPlaylist", const=True, alias='@type')
+    numTracks: Optional[Union[List[Union[int, str]], Union[int, str]]] = Field(
         None,
         description="The number of tracks in this album or playlist.",
     )
-    tracks: Any = Field(
+    tracks: Optional[Union[List[Union[MusicRecording, str]], Union[MusicRecording, str]]] = Field(
         None,
         description="A music recording (track)&#x2014;usually a single song.",
     )
-    track: Any = Field(
+    track: Optional[Union[List[Union[ItemList, MusicRecording, str]], Union[ItemList, MusicRecording, str]]] = Field(
         None,
         description="A music recording (track)&#x2014;usually a single song. If an ItemList is given, the"
      "list should contain items of type MusicRecording.",
     )
-    locals().update({"@type": Field("MusicPlaylist", const=True)})
-
+    
 
 MusicPlaylist.update_forward_refs()
