@@ -1,6 +1,9 @@
 from pydantic import Field
-from typing import Any, Union, List, Optional
 from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
+from typing import List, Optional, Union
+from pydantic_schemaorg.Muscle import Muscle
+from pydantic_schemaorg.SuperficialAnatomy import SuperficialAnatomy
+from pydantic_schemaorg.BrainStructure import BrainStructure
 
 
 class Nerve(AnatomicalStructure):
@@ -10,25 +13,24 @@ class Nerve(AnatomicalStructure):
     See https://schema.org/Nerve.
 
     """
-
-    branch: Any = Field(
+    type_: str = Field("Nerve", const=True, alias='@type')
+    branch: Optional[Union[List[Union[AnatomicalStructure, str]], Union[AnatomicalStructure, str]]] = Field(
         None,
         description="The branches that delineate from the nerve bundle. Not to be confused with [[branchOf]].",
     )
-    nerveMotor: Any = Field(
+    nerveMotor: Optional[Union[List[Union[Muscle, str]], Union[Muscle, str]]] = Field(
         None,
         description="The neurological pathway extension that involves muscle control.",
     )
-    sensoryUnit: Any = Field(
+    sensoryUnit: Optional[Union[List[Union[SuperficialAnatomy, AnatomicalStructure, str]], Union[SuperficialAnatomy, AnatomicalStructure, str]]] = Field(
         None,
         description="The neurological pathway extension that inputs and sends information to the brain or"
      "spinal cord.",
     )
-    sourcedFrom: Any = Field(
+    sourcedFrom: Optional[Union[List[Union[BrainStructure, str]], Union[BrainStructure, str]]] = Field(
         None,
         description="The neurological pathway that originates the neurons.",
     )
-    locals().update({"@type": Field("Nerve", const=True)})
-
+    
 
 Nerve.update_forward_refs()
