@@ -8,8 +8,7 @@ class Nonprofit501c13(USNonprofitType):
     See https://schema.org/Nonprofit501c13.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c13", const=True)})
-
+    type_: str = Field("Nonprofit501c13", const=True, alias='@type')
+    
 
 Nonprofit501c13.update_forward_refs()
