@@ -9,8 +9,7 @@ class Nonprofit501c16(USNonprofitType):
     See https://schema.org/Nonprofit501c16.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c16", const=True)})
-
+    type_: str = Field("Nonprofit501c16", const=True, alias='@type')
+    
 
 Nonprofit501c16.update_forward_refs()
