@@ -9,8 +9,7 @@ class Nonprofit501c17(USNonprofitType):
     See https://schema.org/Nonprofit501c17.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c17", const=True)})
-
+    type_: str = Field("Nonprofit501c17", const=True, alias='@type')
+    
 
 Nonprofit501c17.update_forward_refs()
