@@ -8,8 +8,7 @@ class Nonprofit501c21(USNonprofitType):
     See https://schema.org/Nonprofit501c21.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c21", const=True)})
-
+    type_: str = Field("Nonprofit501c21", const=True, alias='@type')
+    
 
 Nonprofit501c21.update_forward_refs()
