@@ -8,8 +8,7 @@ class Nonprofit501c22(USNonprofitType):
     See https://schema.org/Nonprofit501c22.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c22", const=True)})
-
+    type_: str = Field("Nonprofit501c22", const=True, alias='@type')
+    
 
 Nonprofit501c22.update_forward_refs()
