@@ -9,8 +9,7 @@ class Nonprofit501c25(USNonprofitType):
     See https://schema.org/Nonprofit501c25.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c25", const=True)})
-
+    type_: str = Field("Nonprofit501c25", const=True, alias='@type')
+    
 
 Nonprofit501c25.update_forward_refs()
