@@ -9,8 +9,7 @@ class Nonprofit501c5(USNonprofitType):
     See https://schema.org/Nonprofit501c5.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c5", const=True)})
-
+    type_: str = Field("Nonprofit501c5", const=True, alias='@type')
+    
 
 Nonprofit501c5.update_forward_refs()
