@@ -9,8 +9,7 @@ class Nonprofit501c6(USNonprofitType):
     See https://schema.org/Nonprofit501c6.
 
     """
-
-    locals().update({"@type": Field("Nonprofit501c6", const=True)})
-
+    type_: str = Field("Nonprofit501c6", const=True, alias='@type')
+    
 
 Nonprofit501c6.update_forward_refs()
