@@ -8,8 +8,7 @@ class Nonprofit527(USNonprofitType):
     See https://schema.org/Nonprofit527.
 
     """
-
-    locals().update({"@type": Field("Nonprofit527", const=True)})
-
+    type_: str = Field("Nonprofit527", const=True, alias='@type')
+    
 
 Nonprofit527.update_forward_refs()
